python_json_logger: Python library adding a json log formatter
==============================================================

Description
-----------

Python library adding a json log formatter

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/python-json-logger/

